==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/et_EE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Antud nimi on liiga pikk",
    "The given web address is too long" : "Antud veebiaadress on liiga pikk",
    "The given web address is not a valid URL" : "Antud veebiaadress pole korrektne võrguaadress",
    "The given legal notice address is too long" : "Antud juriidilise teabe aadress on liiga pikk",
    "The given legal notice address is not a valid URL" : "Antud juriidilise teabe aadress pole korrektne võrguaadress",
    "The given privacy policy address is too long" : "Antud privaatsusreeglite aadress on liiga pikk",
    "The given privacy policy address is not a valid URL" : "Antud privaatsusreeglite aadress pole korrektne võrguaadress",
    "The given slogan is too long" : "Antud tunnuslause on liiga pikk",
    "The given color is invalid" : "Antud värv ei sobi",
    "Disable-user-theming should be true or false" : "„Disable-user-theming“ väärtus saab olla kas „true“ või „false“",
    "Saved" : "Salvestatud",
    "Invalid app given" : "Vale rakendus",
    "Invalid type for setting \"defaultApp\" given" : "Seadistuse „defaultApp“ vigane tüüp",
    "Invalid setting key" : "Vigane seadistuste võti",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaaditud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaaditud fail on suurem, kui MAX_FILE_SIZE atribuut, mis oli HTML vormis määratud",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei laaditud üles",
    "Missing a temporary folder" : "Ajutine kaust on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded" : "Faili ei laaditud üles",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sa juba kasutad omaloodud kujundust. Selle rakenduse seadistused ilmselt muudavad nüüd seda.",
    "Theming" : "Kujundused",
    "Appearance and accessibility" : "Välimus ja hõlpsus",
    "PHP Imagick module" : "Moodul PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP moodul „imagick“ pole kasutusel, aga kujundust haldav rakendus on. Et favikonide loomine ja toimiks korrektselt, siis palun lülita see moodul serveri seadistustest sisse.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Selle serveri PHP „imagick“ moodulil puudub SVG tugi. Parema ühilduvusse nimel palun paigalda ta.",
    "Dark theme with high contrast mode" : "Kontrastne tume kujundus",
    "Enable dark high contrast mode" : "Kasuta kontrastset tumedat kujundust",
    "Similar to the high contrast mode, but with dark colours." : "Sarnane kontrastsele režiimile, aga tumedates toonides.",
    "Dark theme" : "Tume kujundus",
    "Enable dark theme" : "Kasuta tumedat kujundust",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Vähendades valgustugevust ja eredust vähendab tume kujundus koormust sinu silmadele.",
    "System default theme" : "Süsteemi vaikimisi kujundus",
    "Enable the system default" : "Kasuta süsteemi vaikimisi kujundust",
    "Using the default system appearance." : "Kasutan süsteemi vaikimisi kujundust.",
    "Dyslexia font" : "Düsleksia font",
    "Enable dyslexia font" : "Kasuta düsleksia fonti",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic on tasuta kirjatüüp/font, mis aitab leevendada mõningaid levinud lugemisvigu, mida põhjustab düsleksia. ",
    "High contrast mode" : "Kõrge kontrastsusega režiim",
    "Enable high contrast mode" : "Kasuta kõrge kontrastsusega režiimi.",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kõrge kontrastsusega režiim, mis hõlbustab liikumist lehel. Visuaalne kvaliteet väheneb, kuid loetavus paraneb. ",
    "Light theme" : "Hele kujundus",
    "Enable the default light theme" : "Kasuta heledat kujundust",
    "The default light appearance." : "Vaikimisi hele kujundus.",
    "Legal notice" : "Juriidiline teave",
    "Privacy policy" : "Privaatsusreeglid",
    "Adjust the Nextcloud theme" : "Muuda Nextcloudi kujundust",
    "Name" : "Nimi",
    "Web link" : "Veebilink",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "Slogan" : "Tunnuslause",
    "Primary color" : "Põhivärv",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Põhivärv on mõeldud lehe oluliste elementude rõhutamiseks. Vastavalt valitud üldkujundusele võib see värv ka natuke kohenduda.",
    "Legal notice link" : "Juriidilise teabe link",
    "Privacy policy link" : "Privaatsustingimuste link",
    "Header logo" : "Päiselogo",
    "Upload new header logo" : "Laadi üles uus päiselogo",
    "Favicon" : "Saidi favikon",
    "Upload new favicon" : "Laadi üles uus saidi favikon",
    "User settings" : "Kasutaja seadistused",
    "Disable user theming" : "Keela kujunduste valimine kasutaja poolt",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Kuigi sina oled seadistanud oma serveri kasutajaliidese kujunduse, siis kasutajad võivad omi taustu ja värve muuta. Kui tahad, et kõik kasutaks ainult sinu tehtud kujundust, siis lülita see eelistus sisse.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Kujundused võimaldavad lihtsalt serveriinstantsi ja toetatud klientide välimust muuta. See on näha kõigile kasutajatele.",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Taustapildi asemele võid sa määrata ka lihtsalt ühe värvi. Kui aga taustapilt on olemas, siis see värv mõjutab rakenduste ikoonide värve.",
    "Background color" : "Taustavärv",
    "Upload new logo" : "Laadi üles uus logo",
    "Logo" : "Logo",
    "Upload new background and login image" : "Laadi üles uus taustapilt ja sisselogimise pilt",
    "Background and login image" : "Taustapilt ja sisselogimise pilt",
    "Advanced options" : "Täpsemad valikud",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Paigalda PHP Imagemagicku lsiamoodul SVG piltide toega, et üleslaaditud logo ja värvi põhjal luua automaatselt favikone. ",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universaalne juurdepääs on meie jaoks väga oluline. Me järgime veebistandardeid ja kontrollime, et kõik oleks kasutatav ka ilma hiireta ja abitarkvara, näiteks ekraani lugejateta. Meie eesmärk on olla vastavuses {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 AA-tasemega, suure kontrastsusega kujunduse puhul isegi AAA-tasemega. ",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Kui leiad mingeid probleeme, siis teata neist {issuetracker}meie veahalduse süsteemis{linkend}. Ja kui soovid kaasa lüüa, siis tule liitu {designteam}meie disainimeeskonnaga{linkend}!",
    "Unable to apply the setting." : "Seadistuse rakendamine ei õnnestu.",
    "Appearance and accessibility settings" : "Välimuse ja hõlpsuse seadistused",
    "Misc accessibility options" : "Varia hõlpsuse seadistused",
    "Enable blur background filter (may increase GPU load)" : "Kasuta tausta hägustamise filtrit (suurendab graafikaprotsessori koormust)",
    "Customization has been disabled by your administrator" : "Kujunduse kohendamine pole peakasutaja poolt lubatud",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Määra oluliste kujunduselementide põhivärv. Sama värv kuulub mõnedes rollides, sealhulgas põhinuppudel, kohendamisele vastavalt hõlbustuse nõuetele.",
    "Background and color" : "Taust ja värvid",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Taustavärvi võid valida mõnest vaikimisi pildikomplekti pildist, oma üleslaaditud pildist või lihtsalt värvinumbri alusel.",
    "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Mõnel juhul klaviatuuri kiirklahvid võivad takistada hõlbustustarvikute tööd. Sellisel puhul saad nad siit välja lülitada. Samaga lülituvad kiirklahvid välja ka kõikides rakendustes.",
    "Disable all keyboard shortcuts" : "Lülita kõik klaviatuuri kiirklahvid välja",
    "Current selected app: {app}, position {position} of {total}" : "Hetkel valitud rakendus: {app}, asukoht {position} / {total}",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "Select a background from your files" : "Vali taustapilt oma failide seast",
    "Select background" : "Vali taust",
    "No background has been selected" : "Ühtegi tausta pole valitud",
    "Custom background" : "Sinu valitud taust",
    "Plain background" : "Lihtne taust",
    "Default background" : "Vaikimisi taust",
    "Theme selection is enforced" : "Kujunduse valik on peakasutaja poolt määratud",
    "Could not set the app order" : "Rakenduste järjekorda ei õnnestunud muuta",
    "Could not reset the app order" : "Rakenduste järjekorda ei õnnestunud lähtestada",
    "Navigation bar settings" : "Rakenduste riba seadistused",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Rakenduste ribal võib objektide järjekorda muuta. Esimene ikoon on vaikimisi rakendus, mis avatakse sisselogimisel või logo klõpsimisel.",
    "The default app can not be changed because it was configured by the administrator." : "Vaikimisi rakendust ei saa muuta, kuna see on peakasutaja poolt ettemääratud.",
    "The app order was changed, to see it in action you have to reload the page." : "Rakenduste järjekord on muudetud. Palun  laadi lehti uuesti, iui soovid näha kuidas see välja näeb.",
    "Reset default app order" : "Lähtesta rakenduste vaikimisi järjekord",
    "Could not set primary color" : "Põhivärvi ei õnnestunud määrata",
    "Reset primary color" : "Lähtesta põhivärv",
    "Could not set global default apps" : "Üldisi vaikimisi rakendusi ei õnnestunud määrata",
    "Default app" : "Vaikimisi rakendus",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Vaikimisi rakendus on see, mis avatakse sisselogimisel või logo klõpsimisel.",
    "Use custom default app" : "Vali endale sobiv vaikimisi rakendus",
    "Global default app" : "Üldine vaikimisi rakendus",
    "Global default apps" : "Üldised vaikimisi rakendused",
    "Default app priority" : "Vaikimisi rakenduste olulisus",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Kui rakendus pole antud kasutaja jaoks sisselülitatud, siis loendist võetakse olulisuselt järgmine rakendus.",
    "Select a custom color" : "Vali oma eelistatud värv",
    "Reset to default" : "Taasta vaikeseaded",
    "Upload" : "Laadi üles",
    "Remove background image" : "Eemalda taustapilt",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universaalne juurdepääs on meie jaoks väga oluline. Me järgime veebistandardeid ja kontrollime, et kõik oleks kasutatav ka ilma hiireta ja abitarkvara, näiteks ekraani lugejateta. Meie eesmärk on olla vastavuses {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA-tasemel, kõrge kontrastsusega kujunduse puhull isegi AAA-tasemel. ",
    ". Unable to apply the setting." : ". Seadistuse rakendamine pole võimalik."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-32.0.5-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/theming/l10n/et_EE.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "Antud nimi on liiga pikk",
    "The given web address is too long" : "Antud veebiaadress on liiga pikk",
    "The given web address is not a valid URL" : "Antud veebiaadress pole korrektne võrguaadress",
    "The given legal notice address is too long" : "Antud juriidilise teabe aadress on liiga pikk",
    "The given legal notice address is not a valid URL" : "Antud juriidilise teabe aadress pole korrektne võrguaadress",
    "The given privacy policy address is too long" : "Antud privaatsusreeglite aadress on liiga pikk",
    "The given privacy policy address is not a valid URL" : "Antud privaatsusreeglite aadress pole korrektne võrguaadress",
    "The given slogan is too long" : "Antud tunnuslause on liiga pikk",
    "The given color is invalid" : "Antud värv ei sobi",
    "%1$s should be true or false" : "„%1$s“ väärtus peaks olema kas „true“ või „false“",
    "%1$s can only be set to %2$s through the API" : "„%1$s“ väärtus saab API-st määratuna olla „%2$s“",
    "Invalid setting key" : "Vigane seadistuste võti",
    "Saved" : "Salvestatud",
    "Invalid app given" : "Vale rakendus",
    "Invalid type for setting \"defaultApp\" given" : "Seadistuse „defaultApp“ vigane tüüp",
    "The file was uploaded" : "Fail laaditi üles",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Üleslaaditud fail on suurem, kui php.ini failis määratud upload_max_filesize",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Üleslaaditud fail on suurem, kui MAX_FILE_SIZE atribuut, mis oli HTML vormis määratud",
    "The file was only partially uploaded" : "Fail laaditi üles ainult osaliselt",
    "No file was uploaded" : "Ühtegi faili ei laaditud üles",
    "Missing a temporary folder" : "Ajutine kaust on puudu",
    "Could not write file to disk" : "Faili kirjutamine kettale ebaõnnestus",
    "A PHP extension stopped the file upload" : "PHP laiendus peatas faili üleslaadimise",
    "No file uploaded" : "Faili ei laaditud üles",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Sa juba kasutad omaloodud kujundust. Selle rakenduse seadistused ilmselt muudavad nüüd seda.",
    "Theming" : "Kujundused",
    "Appearance and accessibility" : "Välimus ja hõlpsus",
    "PHP Imagick module" : "Moodul PHP Imagick",
    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP moodul „imagick“ pole kasutusel, aga kujundust haldav rakendus on. Et favikonide loomine ja toimiks korrektselt, siis palun lülita see moodul serveri seadistustest sisse.",
    "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "Selle serveri PHP „imagick“ moodulil puudub SVG tugi. Parema ühilduvusse nimel palun paigalda ta.",
    "Dark theme with high contrast mode" : "Kontrastne tume kujundus",
    "Enable dark high contrast mode" : "Kasuta kontrastset tumedat kujundust",
    "Similar to the high contrast mode, but with dark colours." : "Sarnane kontrastsele režiimile, aga tumedates toonides.",
    "Dark theme" : "Tume kujundus",
    "Enable dark theme" : "Kasuta tumedat kujundust",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Vähendades valgustugevust ja eredust vähendab tume kujundus koormust sinu silmadele.",
    "System default theme" : "Süsteemi vaikimisi kujundus",
    "Enable the system default" : "Kasuta süsteemi vaikimisi kujundust",
    "Using the default system appearance." : "Kasutan süsteemi vaikimisi kujundust.",
    "Dyslexia font" : "Düsleksia font",
    "Enable dyslexia font" : "Kasuta düsleksia fonti",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic on tasuta kirjatüüp/font, mis aitab leevendada mõningaid levinud lugemisvigu, mida põhjustab düsleksia. ",
    "High contrast mode" : "Kõrge kontrastsusega režiim",
    "Enable high contrast mode" : "Kasuta kõrge kontrastsusega režiimi.",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Kõrge kontrastsusega režiim, mis hõlbustab liikumist lehel. Visuaalne kvaliteet väheneb, kuid loetavus paraneb. ",
    "Light theme" : "Hele kujundus",
    "Enable the default light theme" : "Kasuta heledat kujundust",
    "The default light appearance." : "Vaikimisi hele kujundus.",
    "Legal notice" : "Juriidiline teave",
    "Privacy policy" : "Privaatsusreeglid",
    "Adjust the Nextcloud theme" : "Muuda Nextcloudi kujundust",
    "Could not set global default apps" : "Üldisi vaikimisi rakendusi ei õnnestunud määrata",
    "Navigation bar settings" : "Rakenduste riba seadistused",
    "Default app" : "Vaikimisi rakendus",
    "The default app is the app that is e.g. opened after login or when the logo in the menu is clicked." : "Vaikimisi rakendus on see, mis avatakse sisselogimisel või logo klõpsimisel.",
    "Use custom default app" : "Vali endale sobiv vaikimisi rakendus",
    "Global default app" : "Üldine vaikimisi rakendus",
    "Global default apps" : "Üldised vaikimisi rakendused",
    "Default app priority" : "Vaikimisi rakenduste olulisus",
    "If an app is not enabled for a user, the next app with lower priority is used." : "Kui rakendus pole antud kasutaja jaoks sisselülitatud, siis loendist võetakse olulisuselt järgmine rakendus.",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Kujundused võimaldavad lihtsalt serveriinstantsi ja toetatud klientide välimust muuta. See on näha kõigile kasutajatele.",
    "Name" : "Nimi",
    "Web link" : "Veebilink",
    "Slogan" : "Tunnuslause",
    "a safe home for all your data" : "turvaline koht sinu andmetele",
    "Legal notice link" : "Juriidilise teabe link",
    "Privacy policy link" : "Privaatsustingimuste link",
    "Background and color" : "Taust ja värvid",
    "Primary color" : "Põhivärv",
    "Set the default primary color, used to highlight important elements." : "Seadista vaikimisi põhivärv, mida kasutatakse olulisemate elementide esiletõstmiseks.",
    "The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Sama värv kuulub mõnedes rollides, sealhulgas põhinuppudel, kohendamisele vastavalt hõlbustuse nõuetele.",
    "Background color" : "Taustavärv",
    "When no background image is set the background color will be used." : "Kui taustapilt on seadistamata, on kasutusel taustavärv.",
    "Otherwise the background color is by default generated from the background image, but can be adjusted to fine tune the color of the navigation icons." : "Muul juhul tuletatakse taustavärv vaikimisi taustapildist, kuid juhtnuppude jaoks saad seda veel peenhäälestada.",
    "Use a plain background color instead of a background image." : "Taustapildi asemele kasuta ühtlast taustavärvi.",
    "Remove background image" : "Eemalda taustapilt",
    "Background image" : "Taustapilt",
    "Favicon" : "Saidi favikon",
    "Logo" : "Logo",
    "Navigation bar logo" : "Ülariba logo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Kuigi sina oled seadistanud oma serveri kasutajaliidese kujunduse, siis kasutajad võivad omi taustu ja värve muuta. Kui tahad, et kõik kasutaks ainult sinu tehtud kujundust, siis lülita see eelistus sisse.",
    "Disable user theming" : "Keela kujunduste valimine kasutaja poolt",
    "Current selected app: {app}, position {position} of {total}" : "Hetkel valitud rakendus: {app}, asukoht {position} / {total}",
    "Navigation bar app order" : "Rakenduste järjekord ülaribal",
    "Move up" : "Liiguta ülespoole",
    "Move down" : "Liiguta allapoole",
    "Theme selection is enforced" : "Kujunduse valik on peakasutaja poolt määratud",
    "Could not set the app order" : "Rakenduste järjekorda ei õnnestunud muuta",
    "Could not reset the app order" : "Rakenduste järjekorda ei õnnestunud lähtestada",
    "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "Rakenduste ribal võib objektide järjekorda muuta. Esimene ikoon on vaikimisi rakendus, mis avatakse sisselogimisel või logo klõpsimisel.",
    "The default app can not be changed because it was configured by the administrator." : "Vaikimisi rakendust ei saa muuta, kuna see on peakasutaja poolt ettemääratud.",
    "The app order was changed, to see it in action you have to reload the page." : "Rakenduste järjekord on muudetud. Palun  laadi lehti uuesti, iui soovid näha kuidas see välja näeb.",
    "Reset default app order" : "Lähtesta rakenduste vaikimisi järjekord",
    "Select a background from your files" : "Vali taustapilt oma failide seast",
    "Select background" : "Vali taust",
    "The background can be set to an image from the default set, a custom uploaded image, or a plain color." : "Taustavärvi võid valida mõnest vaikimisi pildikomplekti pildist, oma üleslaaditud pildist või lihtsalt värvinumbri alusel.",
    "Custom background" : "Sinu valitud taust",
    "Plain background" : "Lihtne taust",
    "Default background" : "Vaikimisi taust",
    "Default shipped background images" : "Rakenduse vaikimisi taustapildid",
    "Keyboard shortcuts" : "Klaviatuuri kiirklahvid",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Mõnel juhul klaviatuuri kiirklahvid võivad takistada hõlbustustarvikute tööd. Sellisel puhul saad nad siit välja lülitada. Samaga lülituvad kiirklahvid välja ka kõikides rakendustes.",
    "Disable all keyboard shortcuts" : "Lülita kõik klaviatuuri kiirklahvid välja",
    "Could not set primary color" : "Põhivärvi ei õnnestunud määrata",
    "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "Määra oluliste kujunduselementide põhivärv. Sama värv kuulub mõnedes rollides, sealhulgas põhinuppudel, kohendamisele vastavalt hõlbustuse nõuetele.",
    "Reset primary color" : "Lähtesta põhivärv",
    "Reset to default" : "Taasta vaikeseaded",
    "Non image file selected" : "Ühtegi pildifaili pole valitud",
    "Preview of the selected image" : "Valitud pildi eelvaade",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universaalne juurdepääs on meie jaoks väga oluline. Me järgime veebistandardeid ja kontrollime, et kõik oleks kasutatav ka ilma hiireta ja abitarkvara, näiteks ekraani lugejateta. Meie eesmärk on olla vastavuses {linkstart}Web Content Accessibility Guidelines{linkend} 2.1 AA-tasemega, suure kontrastsusega kujunduse puhul isegi AAA-tasemega. ",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Kui leiad mingeid probleeme, siis teata neist {issuetracker}meie veahalduse süsteemis{linkend}. Ja kui soovid kaasa lüüa, siis tule liitu {designteam}meie disainimeeskonnaga{linkend}!",
    "Unable to apply the setting." : "Seadistuse rakendamine ei õnnestu.",
    "Appearance and accessibility settings" : "Välimuse ja hõlpsuse seadistused",
    "Misc accessibility options" : "Varia hõlpsuse seadistused",
    "Enable blur background filter (may increase GPU load)" : "Kasuta tausta hägustamise filtrit (suurendab graafikaprotsessori koormust)",
    "Customization has been disabled by your administrator" : "Kujunduse kohendamine pole peakasutaja poolt lubatud",
    "Disable-user-theming should be true or false" : "„Disable-user-theming“ väärtus saab olla kas „true“ või „false“",
    "The primary color is used for highlighting elements like important buttons. It might get slightly adjusted depending on the current color schema." : "Põhivärv on mõeldud lehe oluliste elementude rõhutamiseks. Vastavalt valitud üldkujundusele võib see värv ka natuke kohenduda.",
    "Header logo" : "Päiselogo",
    "Upload new header logo" : "Laadi üles uus päiselogo",
    "Upload new favicon" : "Laadi üles uus saidi favikon",
    "User settings" : "Kasutaja seadistused",
    "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "Taustapildi asemele võid sa määrata ka lihtsalt ühe värvi. Kui aga taustapilt on olemas, siis see värv mõjutab rakenduste ikoonide värve.",
    "Upload new logo" : "Laadi üles uus logo",
    "Upload new background and login image" : "Laadi üles uus taustapilt ja sisselogimise pilt",
    "Background and login image" : "Taustapilt ja sisselogimise pilt",
    "Advanced options" : "Täpsemad valikud",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Paigalda PHP Imagemagicku lsiamoodul SVG piltide toega, et üleslaaditud logo ja värvi põhjal luua automaatselt favikone. ",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Universaalne juurdepääs on meie jaoks väga oluline. Me järgime veebistandardeid ja kontrollime, et kõik oleks kasutatav ka ilma hiireta ja abitarkvara, näiteks ekraani lugejateta. Meie eesmärk on olla vastavuses {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 AA-tasemel, kõrge kontrastsusega kujunduse puhull isegi AAA-tasemel. ",
    ". Unable to apply the setting." : ". Seadistuse rakendamine pole võimalik.",
    "No background has been selected" : "Ühtegi tausta pole valitud",
    "Select a custom color" : "Vali oma eelistatud värv",
    "Upload" : "Laadi üles"
},
"nplurals=2; plural=(n != 1);");
